==> nui_media-0.0.1.tar.gz: lib/ui/nui_media_selection_horizontal.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:holding_gesture/holding_gesture.dart';
import 'package:nui_animation/nui_animation.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_media/model/nui_media_list_repo.dart';
import 'package:nui_media/model/nui_media_models.dart';
import 'package:nui_media/nui_media.dart';
import 'package:nui_media/ui/nui_media_preview.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:photo_manager/photo_manager.dart';

typedef MediaFileSelectionListener = void Function(NUIMediaFile added, NUIMediaFile removed, List<NUIMediaFile> selected);

class NUIMediaSelectionHorizontalStyle{
  NUIMediaSelectionHorizontalStyle({this.outlineColor, this.backgroundColor, this.accentColor, this.shadowColor, this.cameraIcon});
  Color outlineColor;
  Color backgroundColor;
  Color accentColor;
  Color shadowColor;
  Widget cameraIcon;

  Widget getCameraIcon() => cameraIcon ?? loadSvg('nui_media_vect_camera.svg', package: "nui_media", width: 24, color: getAccentColor());
  Color getShadowColor() => shadowColor ?? NUIColors.NUIBlack.withOpacity(0.5);
  Color getOutlineColor() => outlineColor ?? NUIColors.NUIGrayOutline;
  Color getBackgroundColor() => backgroundColor ?? NUIColors.NUIWhite;
  Color getAccentColor() => accentColor ?? NUIColors.NUIAccent;
}

class NUIListItemImageHorizontalSkeletal extends NUIListStatefulWidget {
  NUIListItemImageHorizontalSkeletal({this.style, NUIListActionHandler handler, this.widthRatio: 1}): super(handler: handler);
  final NUIMediaSelectionHorizontalStyle style;
  final double widthRatio;
  @override
  _NUIListItemImageHorizontalSkeletalState createState() => _NUIListItemImageHorizontalSkeletalState();
}

class _NUIListItemImageHorizontalSkeletalState extends NUIListState<NUIListItemImageHorizontalSkeletal> {
  @override
  Widget build(BuildContext context) {
    final style = widget.style ?? getConfigData("style") as NUIMediaSelectionHorizontalStyle ?? NUIMediaSelectionHorizontalStyle();

    return Container(
      alignment: Alignment.center,
      width: 72 * widget.widthRatio ?? 1,
      height: 72,
      decoration: NUIBoxDecoration(
        color: style.getOutlineColor(),
        borderRadiusCircular: 10,
        shadowRadius: 4,
        shadowColor: style.getShadowColor()
      ),
      child: Container(
        width: 70 * widget.widthRatio ?? 1,
        height: 70,
        decoration: NUIBoxDecoration(
          color: style.getBackgroundColor(),
          borderRadiusCircular: 9,
          shadowRadius: 0,
        ),
        child: NUIClipView(
          borderRadius: BorderRadius.circular(9),
          child: NUISkeletonContainer(
            baseColor: NUIColors.NUISkeletalLightGray,
            highlightColor: NUIColors.NUISkeletalGray,
            child: NUISkeletonView(
              width: 70 * widget.widthRatio ?? 1,
              height: 70,
            )
          ),
        ),
      ),
    );
  }
}

class NUIListItemImageHorizontal extends NUIListStatefulWidget {
  NUIListItemImageHorizontal({@required this.file, this.style, NUIListActionHandler handler}): super(handler: handler);
  final NUIMediaHorizontalSelection file;
  final NUIMediaSelectionHorizontalStyle style;
  @override
  _NUIListItemImageHorizontalState createState() => _NUIListItemImageHorizontalState();
}

class _NUIListItemImageHorizontalState extends NUIListState<NUIListItemImageHorizontal> {
  @override
  Widget build(BuildContext context) {
    final style = widget.style ?? getConfigData("style") as NUIMediaSelectionHorizontalStyle ?? NUIMediaSelectionHorizontalStyle();
    final selected = getCheckedData(widget.file.file.path) != null;

    return NUIBouncingAnimation(
      scaleFactor: 0.5,
      onTap: (){
        if(selected){
          getHandler().updateCheckedData((map) {
            map.remove(widget.file.file.path);
          });
          getHandler().onItemClick(widget.file, NUIListActions.REMOVE);
        }
        else{
          getHandler().updateCheckedData((map) {
            map[widget.file.file.path] = widget.file.file.path;
          });
          getHandler().onItemClick(widget.file, NUIListActions.NORMAL);
        }
      },
      onLongPress: (){
        getHandler().onItemClick(widget.file, NUIListActions.LONG);
      },
      child: Container(
        alignment: Alignment.center,
        width: 72,
        height: 72,
        decoration: NUIBoxDecoration(
          color: style.getOutlineColor(),
          borderRadiusCircular: 10,
          shadowRadius: 4,
          shadowColor: style.getShadowColor()
        ),
        child: Container(
          width: 70,
          height: 70,
          decoration: NUIBoxDecoration(
            color: style.getBackgroundColor(),
            borderRadiusCircular: 9,
            shadowRadius: 0,
          ),
          child: NUIClipView(
            borderRadius: BorderRadius.circular(9),
            child: Stack(
              children: [
                widget.file.file.thumbData == null
                    ? loadImageLocal(widget.file.file.path, 70, 70)
                    : NUIFutureWidget(
                        futureValue: widget.file.file.thumbData,
                        callback: (state, data, message){
                          if(state == FutureState.SUCCESS) return loadImageLocal(widget.file.file.path, 70, 70, thumbdata: data);
                          return SizedBox(width: 70, height: 70);
                        }),
                SizedBox(width: 70, height: 70),
                Visibility(
                  child: NUIShadowView(
                      padding: EdgeInsets.all(1),
                      margin: EdgeInsets.all(2),
                      opacity: 0.2,
                      blurRadius: 10,
                      child: Icon(Icons.play_arrow, color: NUIColors.NUIWhite,)
                  ),
                  visible: widget.file.file.thumbData != null,
                ),
                Visibility(
                  visible: selected,
                  child: Container(
                    decoration: NUIBoxDecoration(
                      color: style.accentColor.withOpacity(0.4)
                    ),
                    width: 70,
                    height: 70,
                    alignment: Alignment.center,
                    child: NUIShadowView(
                        opacity: 0.2,
                        color: NUIColors.NUIBlack,
                        radius: 35,
                        blurRadius: 15,
                        spreadRadius: 5,
                        child: Icon(Icons.check, color: NUIColors.NUIWhite, size: 25,)
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class NUIListItemCameraHorizontal extends NUIListStatefulWidget {
  NUIListItemCameraHorizontal({this.style, NUIListActionHandler handler}): super(handler: handler);
  final NUIMediaSelectionHorizontalStyle style;
  @override
  _NUIListItemCameraHorizontalState createState() => _NUIListItemCameraHorizontalState();
}

class _NUIListItemCameraHorizontalState extends NUIListState<NUIListItemCameraHorizontal> {
  @override
  Widget build(BuildContext context) {
    final style = widget.style ?? getConfigData("style") as NUIMediaSelectionHorizontalStyle ?? NUIMediaSelectionHorizontalStyle();

    return NUIBouncingAnimation(
      scaleFactor: 0.5,
      onTap: (){
        getHandler().onItemClick("Take Photo", NUIListActions.ADD);
      },
      child: Container(
//      margin: EdgeInsets.only(right: 10),
        alignment: Alignment.center,
        width: 72,
        height: 72,
        decoration: NUIBoxDecoration(
          color: style.getOutlineColor(),
          borderRadiusCircular: 10,
          shadowRadius: 4,
          shadowColor: style.getShadowColor()
        ),
        child: Container(
          width: 70,
          height: 70,
          decoration: NUIBoxDecoration(
            color: style.getBackgroundColor(),
            borderRadiusCircular: 9,
            shadowRadius: 0,
          ),
          child: Align(
            alignment: Alignment.center,
            child: style.getCameraIcon(),
          ),
        ),
      ),
    );
  }
}

class NUIMediaSelectionHorizontalView extends StatefulWidget {
  NUIMediaSelectionHorizontalView({this.limit, this.style, this.requestType: RequestType.all, this.showCamera: true, this.listener});
  final NUIMediaSelectionHorizontalStyle style;
  final RequestType requestType;
  final bool showCamera;
  final int limit;
  final MediaFileSelectionListener listener;

  @override
  _NUIMediaSelectionHorizontalViewState createState() => _NUIMediaSelectionHorizontalViewState();
}

class _NUIMediaSelectionHorizontalViewState extends State<NUIMediaSelectionHorizontalView> {
  NUIListViewBloc<NUIMediaHorizontalSelection, NUIMediaHorizontalSelection> bloc;

  NUIDialog curShowingPreview;
  List<NUIMediaHorizontalSelection> selected = List();

  @override
  void initState(){
    super.initState();
    bloc = NUIListViewBloc<NUIMediaHorizontalSelection, NUIMediaHorizontalSelection>(callbackMethod: (List<NUIMediaHorizontalSelection> current, bool isFirst, bool append, NUIMediaHorizontalSelection cursor) async{
      final hasGalleryPermission = await NUIPermissionUtil.requestPermissions([Permission.storage, Permission.mediaLibrary, Permission.photos]);
      if(hasGalleryPermission) {
        final imagesFuture = NUIMediaUtil.getAllFromGalleryAsNUIMedias(type:widget.requestType ?? RequestType.all, limit: widget.limit ?? 200);
        final waitAtLeast3Secs = await NUIAsync.delayForResult(Duration(seconds: 1), () => null);
        final images = await imagesFuture;
        final result = ListResult<NUIMediaHorizontalSelection, NUIMediaHorizontalSelection>(data: images.map((e) => NUIMediaHorizontalSelection(file: e)).toList(), success: true, message: "Get media selections successful", cursor: null);
        return result;
      }
      else{
        final result = ListResult<NUIMediaHorizontalSelection, NUIMediaHorizontalSelection>(data: [], success: false, message: "Failed to get file selections", cursor: null);
        return result;
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 98,
      child: NUIAnimatedList(
        bloc: bloc,
        repo: NUIMediaListItemRepo(),
        enablePagination: false,
        enableSwipeRefresh: false,
        skeletalCount: 2,
        skeletalInflater: NUILoadingListItem(inflater: (position) => NUIListItemImageHorizontalSkeletal(style: widget.style, widthRatio: position == 0 ? 1.5 : 1.0), shadowRadius: 4),
        configMap: {
          "style": widget.style ?? NUIMediaSelectionHorizontalStyle()
        },
        orientation: Axis.horizontal,
        padding: const EdgeInsets.only(left: 15, top: 10, bottom: 10, right: 15),
        fixedFirstItem: widget.showCamera == true ? (() => NUIMediaHorizontalCameraSelection()) : null,
        initialList: List<NUIMediaHorizontalSelection>(),
        clickListener: (data, position, action){
          if(match(action, NUIListActions.NORMAL)){
            final image = data as NUIMediaHorizontalSelection;
            selected.add(image);
            if(widget.listener != null) widget.listener(image.file, null, selected.map((e) => e.file).toList());
          }
          else if(match(action, NUIListActions.REMOVE)){
            final image = data as NUIMediaHorizontalSelection;
            selected.remove(image);
            if(widget.listener != null) widget.listener(null, image.file, selected.map((e) => e.file).toList());
          }
          else if(match(action, NUIListActions.LONG)){
            final image = data as NUIMediaHorizontalSelection;
            curShowingPreview = showMediaPagerPreview(context, files: [image.file]);
          }
          else if(match(action, NUIListActions.ADD)){
            NUICameraUtil.openCamera(context, enableRecording: true, listener: (file){

            });
          }
        },
      ),
    );
  }
}

==> nui_media-0.0.3.tar.gz: lib/ui/nui_media_selection_horizontal.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:holding_gesture/holding_gesture.dart';
import 'package:nui_animation/nui_animation.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_media/model/nui_media_list_repo.dart';
import 'package:nui_media/model/nui_media_models.dart';
import 'package:nui_media/nui_media.dart';
import 'package:nui_media/ui/nui_media_preview.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:photo_manager/photo_manager.dart';

typedef MediaFileSelectionListener = void Function(NUIMediaFile added, NUIMediaFile removed, List<NUIMediaFile> selected);

class NUIMediaSelectionHorizontalStyle{
  NUIMediaSelectionHorizontalStyle({this.outlineColor, this.backgroundColor, this.accentColor, this.shadowColor, this.cameraIcon});
  Color outlineColor;
  Color backgroundColor;
  Color accentColor;
  Color shadowColor;
  Widget cameraIcon;

  Widget getCameraIcon() => cameraIcon ?? loadSvg('nui_media_vect_camera.svg', package: "nui_media", width: 24, color: getAccentColor());
  Color getShadowColor() => shadowColor ?? NUIColors.NUIBlack.withOpacity(0.5);
  Color getOutlineColor() => outlineColor ?? NUIColors.NUIGrayOutline;
  Color getBackgroundColor() => backgroundColor ?? NUIColors.NUIWhite;
  Color getAccentColor() => accentColor ?? NUIColors.NUIAccent;
}

class NUIListItemImageHorizontalSkeletal extends NUIListStatefulWidget {
  NUIListItemImageHorizontalSkeletal({this.style, NUIListActionHandler handler, this.widthRatio: 1}): super(handler: handler);
  final NUIMediaSelectionHorizontalStyle style;
  final double widthRatio;
  @override
  _NUIListItemImageHorizontalSkeletalState createState() => _NUIListItemImageHorizontalSkeletalState();
}

class _NUIListItemImageHorizontalSkeletalState extends NUIListState<NUIListItemImageHorizontalSkeletal> {
  @override
  Widget build(BuildContext context) {
    final style = widget.style ?? getConfigData("style") as NUIMediaSelectionHorizontalStyle ?? NUIMediaSelectionHorizontalStyle();

    return Container(
      alignment: Alignment.center,
      width: 72 * widget.widthRatio ?? 1,
      height: 72,
      decoration: NUIBoxDecoration(
        color: style.getOutlineColor(),
        borderRadiusCircular: 10,
        shadowRadius: 4,
        shadowColor: style.getShadowColor()
      ),
      child: Container(
        width: 70 * widget.widthRatio ?? 1,
        height: 70,
        decoration: NUIBoxDecoration(
          color: style.getBackgroundColor(),
          borderRadiusCircular: 9,
          shadowRadius: 0,
        ),
        child: NUIClipView(
          borderRadius: BorderRadius.circular(9),
          child: NUISkeletonContainer(
            baseColor: NUIColors.NUISkeletalLightGray,
            highlightColor: NUIColors.NUISkeletalGray,
            child: NUISkeletonView(
              width: 70 * widget.widthRatio ?? 1,
              height: 70,
            )
          ),
        ),
      ),
    );
  }
}

class NUIListItemImageHorizontal extends NUIListStatefulWidget {
  NUIListItemImageHorizontal({@required this.file, this.style, NUIListActionHandler handler}): super(handler: handler);
  final NUIMediaHorizontalSelection file;
  final NUIMediaSelectionHorizontalStyle style;
  @override
  _NUIListItemImageHorizontalState createState() => _NUIListItemImageHorizontalState();
}

class _NUIListItemImageHorizontalState extends NUIListState<NUIListItemImageHorizontal> {
  @override
  Widget build(BuildContext context) {
    final style = widget.style ?? getConfigData("style") as NUIMediaSelectionHorizontalStyle ?? NUIMediaSelectionHorizontalStyle();
    final selected = getCheckedData(widget.file.file.path) != null;

    return NUIBouncingAnimation(
      scaleFactor: 0.5,
      onTap: (){
        if(selected){
          getHandler().updateCheckedData((map) {
            map.remove(widget.file.file.path);
          });
          getHandler().onItemClick(widget.file, NUIListActions.REMOVE);
        }
        else{
          getHandler().updateCheckedData((map) {
            map[widget.file.file.path] = widget.file.file.path;
          });
          getHandler().onItemClick(widget.file, NUIListActions.NORMAL);
        }
      },
      onLongPress: (){
        getHandler().onItemClick(widget.file, NUIListActions.LONG);
      },
      child: Container(
        alignment: Alignment.center,
        width: 72,
        height: 72,
        decoration: NUIBoxDecoration(
          color: style.getOutlineColor(),
          borderRadiusCircular: 10,
          shadowRadius: 4,
          shadowColor: style.getShadowColor()
        ),
        child: Container(
          width: 70,
          height: 70,
          decoration: NUIBoxDecoration(
            color: style.getBackgroundColor(),
            borderRadiusCircular: 9,
            shadowRadius: 0,
          ),
          child: NUIClipView(
            borderRadius: BorderRadius.circular(9),
            child: Stack(
              children: [
                widget.file.file.thumbData == null
                    ? loadImageLocal(widget.file.file.path, 70, 70)
                    : NUIFutureWidget(
                        futureValue: widget.file.file.thumbData,
                        callback: (state, data, message){
                          if(state == FutureState.SUCCESS) return loadImageLocal(widget.file.file.path, 70, 70, thumbdata: data);
                          return SizedBox(width: 70, height: 70);
                        }),
                SizedBox(width: 70, height: 70),
                Visibility(
                  visible: selected,
                  child: Container(
                    decoration: NUIBoxDecoration(
                      color: style.accentColor.withOpacity(0.4)
                    ),
                    width: 70,
                    height: 70,
                    alignment: Alignment.bottomRight,
                    child: NUIShadowView(
                        padding: EdgeInsets.all(1),
                        margin: EdgeInsets.all(2),
                        opacity: 0.2,
                        blurRadius: 10,
                        radius: 35,
                        spreadRadius: 5,
                        child: Icon(Icons.check_circle, color: NUIColors.NUIWhite)
                    ),
                  ),
                ),
                Visibility(
                  child: NUIShadowView(
                      padding: EdgeInsets.all(1),
                      margin: EdgeInsets.all(2),
                      opacity: 0.2,
                      blurRadius: 10,
                      child: Icon(Icons.play_arrow, color: NUIColors.NUIWhite,)
                  ),
                  visible: widget.file.file.thumbData != null,
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class NUIListItemCameraHorizontal extends NUIListStatefulWidget {
  NUIListItemCameraHorizontal({this.style, NUIListActionHandler handler}): super(handler: handler);
  final NUIMediaSelectionHorizontalStyle style;
  @override
  _NUIListItemCameraHorizontalState createState() => _NUIListItemCameraHorizontalState();
}

class _NUIListItemCameraHorizontalState extends NUIListState<NUIListItemCameraHorizontal> {
  @override
  Widget build(BuildContext context) {
    final style = widget.style ?? getConfigData("style") as NUIMediaSelectionHorizontalStyle ?? NUIMediaSelectionHorizontalStyle();

    return NUIBouncingAnimation(
      scaleFactor: 0.5,
      onTap: (){
        getHandler().onItemClick("Take Photo", NUIListActions.ADD);
      },
      child: Container(
//      margin: EdgeInsets.only(right: 10),
        alignment: Alignment.center,
        width: 72,
        height: 72,
        decoration: NUIBoxDecoration(
          color: style.getOutlineColor(),
          borderRadiusCircular: 10,
          shadowRadius: 4,
          shadowColor: style.getShadowColor()
        ),
        child: Container(
          width: 70,
          height: 70,
          decoration: NUIBoxDecoration(
            color: style.getBackgroundColor(),
            borderRadiusCircular: 9,
            shadowRadius: 0,
          ),
          child: Align(
            alignment: Alignment.center,
            child: style.getCameraIcon(),
          ),
        ),
      ),
    );
  }
}

class NUIMediaSelectionHorizontalView extends StatefulWidget {
  NUIMediaSelectionHorizontalView({this.limit, this.style, this.requestType: RequestType.all, this.showCamera: true, this.listener});
  final NUIMediaSelectionHorizontalStyle style;
  final RequestType requestType;
  final bool showCamera;
  final int limit;
  final MediaFileSelectionListener listener;

  @override
  _NUIMediaSelectionHorizontalViewState createState() => _NUIMediaSelectionHorizontalViewState();
}

class _NUIMediaSelectionHorizontalViewState extends State<NUIMediaSelectionHorizontalView> {
  NUIListViewBloc<NUIMediaHorizontalSelection, NUIMediaHorizontalSelection> bloc;

  NUIDialog curShowingPreview;
  List<NUIMediaHorizontalSelection> selected = List();

  @override
  void initState(){
    super.initState();
    bloc = NUIListViewBloc<NUIMediaHorizontalSelection, NUIMediaHorizontalSelection>(callbackMethod: (List<NUIMediaHorizontalSelection> current, bool isFirst, bool append, NUIMediaHorizontalSelection cursor) async{
      final hasGalleryPermission = await NUIPermissionUtil.requestPermissions([Permission.storage, Permission.mediaLibrary, Permission.photos]);
      if(hasGalleryPermission) {
        final imagesFuture = NUIMediaUtil.getAllFromGalleryAsNUIMedias(type:widget.requestType ?? RequestType.all, limit: widget.limit ?? 200);
        final waitAtLeast3Secs = await NUIAsync.delayForResult(Duration(seconds: 1), () => null);
        final images = await imagesFuture;
        final result = ListResult<NUIMediaHorizontalSelection, NUIMediaHorizontalSelection>(data: images.map((e) => NUIMediaHorizontalSelection(file: e)).toList(), success: true, message: "Get media selections successful", cursor: null);
        return result;
      }
      else{
        final result = ListResult<NUIMediaHorizontalSelection, NUIMediaHorizontalSelection>(data: [], success: false, message: "Failed to get file selections", cursor: null);
        return result;
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 98,
      child: NUIAnimatedList(
        bloc: bloc,
        repo: NUIMediaListItemRepo(),
        enablePagination: false,
        enableSwipeRefresh: false,
        skeletalCount: 2,
        skeletalInflater: NUILoadingListItem(inflater: (position) => NUIListItemImageHorizontalSkeletal(style: widget.style, widthRatio: position == 0 ? 1.5 : 1.0), shadowRadius: 4),
        configMap: {
          "style": widget.style ?? NUIMediaSelectionHorizontalStyle()
        },
        orientation: Axis.horizontal,
        padding: const EdgeInsets.only(left: 15, top: 10, bottom: 10, right: 15),
        fixedFirstItem: widget.showCamera == true ? (() => NUIMediaHorizontalCameraSelection()) : null,
        initialList: List<NUIMediaHorizontalSelection>(),
        clickListener: (data, position, action){
          if(match(action, NUIListActions.NORMAL)){
            final image = data as NUIMediaHorizontalSelection;
            selected.add(image);
            if(widget.listener != null) widget.listener(image.file, null, selected.map((e) => e.file).toList());
          }
          else if(match(action, NUIListActions.REMOVE)){
            final image = data as NUIMediaHorizontalSelection;
            selected.remove(image);
            if(widget.listener != null) widget.listener(null, image.file, selected.map((e) => e.file).toList());
          }
          else if(match(action, NUIListActions.LONG)){
            final image = data as NUIMediaHorizontalSelection;
            curShowingPreview = showMediaPagerPreview(context, files: [image.file]);
          }
          else if(match(action, NUIListActions.ADD)){
            NUICameraUtil.openCamera(context, enableRecording: true, listener: (file){

            });
          }
        },
      ),
    );
  }
}
